@@ -86,6 +86,7 @@ class ClickReviewSecurity(ClickReview):
                                              # 'camera', non-functional ATM
                                              'content_exchange',
                                              'content_exchange_source',
+                                             'keep-display-on',
                                              'location',
                                              'networking',
                                              'video',
@@ -1205,7 +1206,13 @@ class ClickReviewSecurity(ClickReview):
                         "'%s'" % app
                 self._add_result(t, n, s)
 
-        # TODO: error if specified
+                if 'security-policy' in item:
+                    t = 'error'
+                    n = 'yaml_policy_present'
+                    s = "(MANUAL REVIEW) 'security-policy' not allowed"
+                    l = 'https://developer.ubuntu.com/en/snappy/guides/security-policy/'
+                    m = True
+                    self._add_result(t, n, s, link=l, manual_review=m)
 
     def check_security_yaml_combinations(self):
         '''Verify security yaml uses valid combinations'''
